package com.huiju.estateagents.controller;

import ch.qos.logback.core.status.StatusUtil;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.common.JWTUtils;
import com.huiju.estateagents.entity.TaCheckin;
import com.huiju.estateagents.entity.TaPerson;
import com.huiju.estateagents.service.ITaCheckinService;
import com.huiju.estateagents.service.ITaPersonService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

import javax.servlet.http.HttpServletRequest;
import java.time.LocalDateTime;
import java.util.List;


/**
 * <p>
    *   前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-07-24
 */
@RestController
@RequestMapping("/api")
public class TaCheckinController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaCheckinController.class);

    @Autowired
    public ITaCheckinService iTaCheckinService;
    @Autowired
    public ITaPersonService iTaPersonService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taCheckin/activity/{activity}",method= RequestMethod.GET)
    public ResponseBean taCheckinList(@PathVariable String activity,
                                      @RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                      @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaCheckin> pg = new Page<>(pageNum, pageSize);
            IPage<TaCheckin> result = iTaCheckinService.getUndisplayedCustomerList(pg,activity);
            for (int i = 0;i<result.getRecords().size();i++){
                result.getRecords().get(i).setStatus(1);
            }
            iTaCheckinService.updateBatchById(result.getRecords());
            responseBean.success(result);
        }catch (Exception e){
            logger.error("taCheckinList -=- {}",e.toString());
            responseBean.error(e.getMessage(),ResponseBean.ERROR_UNAVAILABLE);
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param activity 实体对象
     * @return
     */
    @RequestMapping(value="/wx/taCheckin/activity/{activity}",method= RequestMethod.POST)
    public ResponseBean taCheckinAdd(@PathVariable String activity, HttpServletRequest request){
        ResponseBean responseBean = new ResponseBean();
        String openid = JWTUtils.getSubject(request);
        List<TaPerson> taPersons = iTaPersonService.getPersonsByOpenId(openid);
        if (null == taPersons || taPersons.size() != 1) {
            return ResponseBean.error("验证人员信息失败", ResponseBean.ERROR_UNAVAILABLE);
        }
        TaPerson person = taPersons.get(0);


        try {
            if(iTaCheckinService.isCustomerChecked(activity,person.getPersonId())>0){
                ResponseBean.success("您已签到过此活动");
            }else {
                TaCheckin taCheckin = new TaCheckin();
                taCheckin.setStatus(0);
                taCheckin.setPersonId(person.getPersonId());
                taCheckin.setActivity(activity);
                taCheckin.setName(person.getNickname());
                taCheckin.setAvatar(person.getAvatarurl());
                taCheckin.setCheckinTime(LocalDateTime.now());
                if (iTaCheckinService.save(taCheckin)){
                    responseBean.success(taCheckin);
                }else {
                    responseBean.error("保存失败",ResponseBean.ERROR_UNAVAILABLE);
                }
            }

        }catch (Exception e){
            logger.error("taCheckinAdd -=- {}",e.toString());
            responseBean.error("保存失败"+e.getMessage(),ResponseBean.ERROR_UNAVAILABLE);
        }
        return responseBean;
    }

//    /**
//     * 根据id删除对象
//     * @param id  实体ID
//     */
//    @ResponseBody
//    @RequestMapping(value="/taCheckin/{id}", method= RequestMethod.DELETE)
//    public ResponseBean taCheckinDelete(@PathVariable Integer id){
//        ResponseBean responseBean = new ResponseBean();
//        try {
//            if(iTaCheckinService.removeById(id)){
//                responseBean.addSuccess("success");
//            }else {
//                responseBean.addError("fail");
//            }
//        }catch (Exception e){
//            logger.error("taCheckinDelete -=- {}",e.toString());
//            responseBean.addError(e.getMessage());
//        }
//        return responseBean;
//    }

//    /**
//     * 修改对象
//     * @param id  实体ID
//     * @param taCheckin 实体对象
//     * @return
//     */
//    @RequestMapping(value="/taCheckin/{id}",method= RequestMethod.PUT)
//    public ResponseBean taCheckinUpdate(@PathVariable Integer id,
//                                        @RequestBody TaCheckin taCheckin){
//        ResponseBean responseBean = new ResponseBean();
//        try {
//            if (iTaCheckinService.updateById(taCheckin)){
//                responseBean.addSuccess(taCheckin);
//            }else {
//                responseBean.addError("fail");
//            }
//        }catch (Exception e){
//            logger.error("taCheckinUpdate -=- {}",e.toString());
//            responseBean.addError(e.getMessage());
//        }
//        return responseBean;
//    }

//    /**
//     * 根据id查询对象
//     * @param id  实体ID
//     */
//    @RequestMapping(value="/taCheckin/{id}",method= RequestMethod.GET)
//    public ResponseBean taCheckinGet(@PathVariable Integer id){
//        ResponseBean responseBean = new ResponseBean();
//        try {
//            responseBean.addSuccess(iTaCheckinService.getById(id));
//        }catch (Exception e){
//            logger.error("taCheckinDelete -=- {}",e.toString());
//            responseBean.addError(e.getMessage());
//        }
//        return responseBean;
//    }
}
