package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.TaNews;
import com.huiju.estateagents.service.ITaNewsService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 资讯表  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-07-25
 */
@RestController
@RequestMapping("/api")
public class TaNewsController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaNewsController.class);

    @Autowired
    public ITaNewsService iTaNewsService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taNews",method= RequestMethod.GET)
    public ResponseBean taNewsList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                   @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                   @RequestParam(value = "buildingId", required = false) String buildingId,
                                   @RequestParam(value = "orgId", required = false) Integer orgId,
                                   @RequestParam(value = "newsTypeId", required = false) Integer newsTypeId,
                                   @RequestParam(value = "newsStatus", required = false) Integer newsStatus){
        ResponseBean responseBean = iTaNewsService.getList(pageNum, pageSize, buildingId, orgId, newsTypeId, newsStatus);
        return responseBean;
    }

    /**
     * 微信 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/wx/taNews",method= RequestMethod.GET)
    public ResponseBean wxTaNewsList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                   @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = iTaNewsService.getList(pageNum, pageSize, null, null, null, null);
        return responseBean;
    }

    /**
     * 保存对象
     * @param taNews 实体对象
     * @return
     */
    @RequestMapping(value="/taNews",method= RequestMethod.POST)
    public ResponseBean taNewsAdd(@RequestBody TaNews taNews){
        ResponseBean responseBean = iTaNewsService.addTaNews(taNews);
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taNews/{id}", method= RequestMethod.DELETE)
    public ResponseBean taNewsDelete(@PathVariable Integer id){
        ResponseBean responseBean = iTaNewsService.deleteTaNews(id);
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taNews 实体对象
     * @return
     */
    @RequestMapping(value="/taNews/{id}",method= RequestMethod.PUT)
    public ResponseBean taNewsUpdate(@PathVariable Integer id,
                                        @RequestBody TaNews taNews){
        taNews.setNewsId(id);
        ResponseBean responseBean = iTaNewsService.updateTaNews(taNews);
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taNews/{id}",method= RequestMethod.GET)
    public ResponseBean taNewsGet(@PathVariable Integer id){
        ResponseBean responseBean = iTaNewsService.getTaNewsById(id);
        return responseBean;
    }

    /**
     * 微信 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/wx/taNews/{id}",method= RequestMethod.GET)
    public ResponseBean wxTaNewsGet(@PathVariable Integer id){
        ResponseBean responseBean = iTaNewsService.getWxTaNewsById(id);
        return responseBean;
    }

    /**
     * 微信 资讯阅读量+1
     * @param id
     * @return
     */
    @RequestMapping(value = "/wx/taNews/pvNum/{id}", method = RequestMethod.PUT)
    public ResponseBean wxTaPvNum(@PathVariable Integer id) {
        ResponseBean responseBean = iTaNewsService.wxTaPvNum(id);
        return responseBean;
    }
}
