package com.huiju.estateagents.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.huiju.estateagents.base.BaseController;
import com.huiju.estateagents.base.ResponseBean;
import com.huiju.estateagents.entity.TaPointsExchange;
import com.huiju.estateagents.service.ITaPointsExchangeService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.ResponseBody;
import org.springframework.web.bind.annotation.RestController;

/**
 * <p>
    * 积分兑换记录  前端控制器
    * </p>
 *
 * @author jobob
 * @since 2019-07-25
 */
@RestController
@RequestMapping("/api")
public class TaPointsExchangeController extends BaseController {

    private final Logger logger = LoggerFactory.getLogger(TaPointsExchangeController.class);

    @Autowired
    public ITaPointsExchangeService iTaPointsExchangeService;


    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/taPointsExchange",method= RequestMethod.GET)
    public ResponseBean taPointsExchangeList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                             @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
		    IPage<TaPointsExchange> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaPointsExchange> queryWrapper = new QueryWrapper<>();
            queryWrapper.orderByDesc("create_date");

            IPage<TaPointsExchange> result = iTaPointsExchangeService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taPointsExchangeList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 保存对象
     * @param taPointsExchange 实体对象
     * @return
     */
    @RequestMapping(value="/taPointsExchange",method= RequestMethod.POST)
    public ResponseBean taPointsExchangeAdd(@RequestBody TaPointsExchange taPointsExchange){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaPointsExchangeService.save(taPointsExchange)){
                responseBean.addSuccess(taPointsExchange);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taPointsExchangeAdd -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     */
    @ResponseBody
    @RequestMapping(value="/taPointsExchange/{id}", method= RequestMethod.DELETE)
    public ResponseBean taPointsExchangeDelete(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            if(iTaPointsExchangeService.removeById(id)){
                responseBean.addSuccess("success");
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taPointsExchangeDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 修改对象
     * @param id  实体ID
     * @param taPointsExchange 实体对象
     * @return
     */
    @RequestMapping(value="/taPointsExchange/{id}",method= RequestMethod.PUT)
    public ResponseBean taPointsExchangeUpdate(@PathVariable Integer id,
                                        @RequestBody TaPointsExchange taPointsExchange){
        ResponseBean responseBean = new ResponseBean();
        try {
            if (iTaPointsExchangeService.updateById(taPointsExchange)){
                responseBean.addSuccess(taPointsExchange);
            }else {
                responseBean.addError("fail");
            }
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taPointsExchangeUpdate -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }

    /**
     * 根据id查询对象
     * @param id  实体ID
     */
    @RequestMapping(value="/taPointsExchange/{id}",method= RequestMethod.GET)
    public ResponseBean taPointsExchangeGet(@PathVariable Integer id){
        ResponseBean responseBean = new ResponseBean();
        try {
            responseBean.addSuccess(iTaPointsExchangeService.getById(id));
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taPointsExchangeDelete -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
    
    /**
     * 分页查询列表
     * @param pageNum
     * @param pageSize
     * @return
     */
    @RequestMapping(value="/wx/taPointsExchange",method= RequestMethod.GET)
    public ResponseBean wxPointsExchangeList(@RequestParam(value ="pageNum",defaultValue = "1") Integer pageNum,
                                             @RequestParam(value ="pageSize",defaultValue = "10") Integer pageSize,
                                             @RequestParam("buildingId") Integer buildingId){
        ResponseBean responseBean = new ResponseBean();
        try {
            //使用分页插件
            IPage<TaPointsExchange> pg = new Page<>(pageNum, pageSize);
            QueryWrapper<TaPointsExchange> queryWrapper = new QueryWrapper<>();
            queryWrapper.eq("building_id",buildingId);
            queryWrapper.orderByDesc("create_date");
            
            IPage<TaPointsExchange> result = iTaPointsExchangeService.page(pg, queryWrapper);
            responseBean.addSuccess(result);
        }catch (Exception e){
            e.printStackTrace();
            logger.error("taPointsExchangeList -=- {}",e.toString());
            responseBean.addError(e.getMessage());
        }
        return responseBean;
    }
}
